@@ -1,16 +1,22 @@
+from __future__ import absolute_import
+from __future__ import print_function
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str, range, object
 import os
 import sys
 import requests
-import urllib
+import urllib.request, urllib.parse, urllib.error
 from os.path import expanduser
-from token_api import Token_api as token_api
-from meta_utils import MetaDataUtils as Metadata
+from csr_cloud.token_api import Token_api as token_api
+from csr_cloud.meta_utils import MetaDataUtils as Metadata
 import logging
 import ipaddress
 from logging.handlers import RotatingFileHandler
 import datetime
 import json
 import shutil
+import subprocess
 
 log = logging.getLogger('HA')
 log.setLevel(logging.INFO)
@@ -19,22 +25,31 @@ home = expanduser("~")
 event_dir = "%s/cloud/HA/events" % home
 
 
-class csr_ha():
+class csr_ha(object):
     def __init__(self):                                                                 #pragma nocover
         self.cert_file = "/etc/ssl/certs/ca-bundle.trust.crt"
-        sys.path.append(home + '/.local/lib/python2.7/site-packages/csr_ha/client_api')
-        sys.path.append(home + '.local/lib/python2.7/site-packages/csr_ha/server')
+        site=subprocess.check_output("{} -m site --user-site".format(sys.executable), shell=True)
+        sys.path.append(site + b'/csr_ha/client_api')
+        sys.path.append(site + b'/csr_ha/server')
 
         # Setting event_logger for route events for fail-safe approach
         # Ideally csr_ha is responsible for setting it up using set_event_logger
         self.event_logger = log
         self.event_log_file = ""
 
-        if os.path.exists("/home/guestshell/cloud/HA/csr_ha.log"):
-            if os.path.getsize("/home/guestshell/cloud/HA/csr_ha.log") > 15000000:
-                shutil.copy('/home/guestshell/cloud/HA/csr_ha.log', '/bootflash/csr_ha.log')
+        try:
+            if (os.path.exists("/home/guestshell/cloud/HA/csr_ha.log") and os.path.getsize("/home/guestshell/cloud/HA/csr_ha.log") > 15000000):
+                if os.path.exists("/bootflash/guest-share/"):
+                    shutil.copy('/home/guestshell/cloud/HA/csr_ha.log', '/bootflash/guest-share/csr_ha.log')
+                else:
+                    shutil.copy('/home/guestshell/cloud/HA/csr_ha.log', '/bootflash/')
                 os.remove('/home/guestshell/cloud/HA/csr_ha.log')
-
+        except Exception as e:
+            #This is backing up the csr_ha.log file, if file size is above 10 MB. 
+            #Log the exception and continue so that HACsr object initialization doesn't fail because of this
+            self.log.exception("Exception in init is {e}".format(e=e))
+            self.log.info("Backing up csr_ha.log to cloud/HA/csr_ha_backup.log")
+            shutil.move("/home/guestshell/cloud/HA/csr_ha.log", "/home/guestshell/cloud/HA/csr_ha_backup.log")
 
     def create_event_logger(self, node, event_type, directory_name):
         '''
@@ -456,7 +471,7 @@ class csr_ha():
 
         write_rsp_content = ""
         if write_rsp_to_file == True:
-            self.event_logger.info("Set route response:\n%s" % response.txt)
+            self.event_logger.info("Set route response:\n%s" % response.text)
 
         return response.status_code
 
@@ -486,26 +501,26 @@ class csr_ha():
 
         if event_type == 'verify':
             node_verified = True
-            if (not (node.has_key('cloud'))):
+            if (not ('cloud' in node)):
                 self.event_logger.info("Missing required parameter -p cloud")
                 node_verified = False
-            if (not (node.has_key('subscriptionId'))):
+            if (not ('subscriptionId' in node)):
                 self.event_logger.info("Missing required parameter -s subscriptionId")
                 node_verified = False
-            if (not (node.has_key('resourceGroup'))):
+            if (not ('resourceGroup' in node)):
                 self.event_logger.info("Missing required parameter -g resourceGroup")
                 node_verified = False
-            if (not (node.has_key('routeTableName'))):
+            if (not ('routeTableName' in node)):
                 self.event_logger.info("Missing required parameter -t routeTableName")
                 node_verified = False
-            if (not (node.has_key('nextHop'))):
+            if (not ('nextHop' in node)):
                 self.event_logger.info("Missing required parameter -n nextHopIpAddress")
                 node_verified = False
-            if node.has_key('appId'):
-                if (not (node.has_key('tenantId'))):
+            if 'appId' in node:
+                if (not ('tenantId' in node)):
                     self.event_logger.info("Missing required parameter -d tenantId")
                     node_verified = False
-                if (not (node.has_key('appKey'))):
+                if (not ('appKey' in node)):
                     self.event_logger.info("Missing required parameter -k applicationKey")
                     node_verified = False
 
@@ -515,17 +530,17 @@ class csr_ha():
             else:
                 return 'ERR1'
         else:
-            if ((node.has_key('index')) and
-                    (node.has_key('cloud')) and
-                    (node.has_key('routeTableName')) and
-                    (node.has_key('subscriptionId')) and
-                    (node.has_key('resourceGroup')) and
-                    (node.has_key('nextHop'))):
+            if (('index' in node) and
+                    ('cloud' in node) and
+                    ('routeTableName' in node) and
+                    ('subscriptionId' in node) and
+                    ('resourceGroup' in node) and
+                    ('nextHop' in node)):
 
-                if node.has_key('appId'):
-                    if (not (node.has_key('tenantId'))):
+                if 'appId' in node:
+                    if (not ('tenantId' in node)):
                         return "ERR1"
-                    elif (not (node.has_key('appKey'))):
+                    elif (not ('appKey' in node)):
                         return "ERR1"
                 return 'OK'
             else:
@@ -555,7 +570,7 @@ class csr_ha():
             keyword = "appKey"
         else:
             log.error("Invalid command format %s" % cmd)
-            print "Invalid command format %s" % cmd
+            print("Invalid command format %s" % cmd)
             return "Error"
 
         return keyword
@@ -565,11 +580,11 @@ class csr_ha():
         # Make any cloud specific changes to the parameters
         node = params
 
-        if params.has_key('appKey'):
+        if 'appKey' in params:
             # Check if the key is URL encoded. If so, decode it.
             app_key = params['appKey']
             if len(app_key) > 44 and app_key.count('%') > 0:
-                node['appKey'] = urllib.unquote(app_key)
+                node['appKey'] = urllib.parse.unquote(app_key)
 
         return node
 
@@ -696,7 +711,7 @@ access to the route table to be able to change the routes. At last, please do
         :return: Returns 0 or 1 based on the nextHop
         '''
         try:
-            ipaddress.ip_address(unicode(nextHop))
+            ipaddress.ip_address(str(nextHop))
             return 0
         except Exception as e:
             return 1
@@ -746,16 +761,16 @@ access to the route table to be able to change the routes. At last, please do
                     '''.format(str(node['index']))
         response['code'] = 200
         response['msg'] = ""
-        if not node.has_key("resourceGroup") or not node.has_key('subscriptionId'):
+        if "resourceGroup" not in node or 'subscriptionId' not in node:
             response['code'] = 199
             response['msg'] = "Unable to validate nodes. Please verify node configuration"
-            if not node.has_key("resourceGroup"):
+            if "resourceGroup" not in node:
                 response['msg'] =  response['msg'] + "\n199: resourceGroup not found in input parameters"
-            if not node.has_key("subscriptionId"):
+            if "subscriptionId" not in node:
                 response['msg'] = response['msg'] + "\n199: subscriptionId not found in input parameters"
             return response
 
-        if (not node.has_key('appId') or not node.has_key('subscriptionId') or not node.has_key('tenantId') or not node.has_key('appKey')) and node.has_key('cloud') != 'azure':
+        if ('appId' not in node or 'subscriptionId' not in node or 'tenantId' not in node or 'appKey' not in node) and ('cloud' in node) != 'azure':
             log.warning(resp_msg)
             response['code'] = 199
             response['msg'] = resp_msg
@@ -764,7 +779,7 @@ access to the route table to be able to change the routes. At last, please do
         routetable = self.get_route_table(node)
         if routetable is not None:
             # Walk through all the routes in the current route table
-            if node.has_key("route"):
+            if "route" in node:
                 for i, route in enumerate(routetable["properties"]["routes"]):
                     if route['properties']['nextHopType'] == 'VirtualAppliance':
                         # Updating a single route in the table.  Need to find the right one.
