@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
+from __future__ import print_function
 import sys
-from csr_cloud.token_api import Token_api as token_api
+from token_api import Token_api as token_api
 import argparse
 
 
@@ -26,13 +27,13 @@ def main(argv):
     # Verify server is up
     rc = conn.is_server_up()
     if rc != 0:
-        print "failed connection to token manager rc=%d" % rc
+        print("failed connection to token manager rc=%d" % rc)
         sys.exit()
 
     # Request server to clear the default AAD application
     result = conn.set_default_aad_app(args.p, args.d, args.a, args.k)
     if result != 'OK':
-        print "Failed to set default AAD application: %s" % result
+        print("Failed to set default AAD application: %s" % result)
         sys.exit()
 
     conn.disconnect()
